summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorCalum Lind <calumlind+deluge@gmail.com>2013-06-09 02:30:26 +0100
committerCalum Lind <calumlind+deluge@gmail.com>2013-06-09 02:35:10 +0100
commit3cc43f63a0b049c5702765c3c3e2aacf3ec8fd5a (patch)
tree53a699a706df70d8d638cdcc42e59f2cf7a6cffc
parent27bfa5a64933a46cb3b6edc73d64fd401953ea09 (diff)
downloaddeluge-3cc43f63a0b049c5702765c3c3e2aacf3ec8fd5a.tar.gz
deluge-3cc43f63a0b049c5702765c3c3e2aacf3ec8fd5a.tar.bz2
deluge-3cc43f63a0b049c5702765c3c3e2aacf3ec8fd5a.zip
Fix #2338 : Spelling mistake with occurred
-rw-r--r--deluge/core/core.py2
-rw-r--r--deluge/plugins/blocklist/blocklist/core.py20
-rw-r--r--deluge/ui/tracker_icons.py6
-rw-r--r--deluge/ui/web/json_api.py6
4 files changed, 17 insertions, 17 deletions
diff --git a/deluge/core/core.py b/deluge/core/core.py
index dd7648dfa..1ca6f92d8 100644
--- a/deluge/core/core.py
+++ b/deluge/core/core.py
@@ -277,7 +277,7 @@ class Core(component.Component):
result.addCallbacks(on_download_success, on_download_fail)
else:
# Log the error and pass the failure onto the client
- log.error("Error occured downloading torrent from %s", url)
+ log.error("Error occurred downloading torrent from %s", url)
log.error("Reason: %s", failure.getErrorMessage())
result = failure
return result
diff --git a/deluge/plugins/blocklist/blocklist/core.py b/deluge/plugins/blocklist/blocklist/core.py
index 0908ad85d..12cee457f 100644
--- a/deluge/plugins/blocklist/blocklist/core.py
+++ b/deluge/plugins/blocklist/blocklist/core.py
@@ -163,7 +163,7 @@ class Core(CorePluginBase):
def get_config(self):
"""
Returns the config dictionary
-
+
:returns: the config dictionary
:rtype: dict
"""
@@ -184,7 +184,7 @@ class Core(CorePluginBase):
def get_status(self):
"""
Returns the status of the plugin
-
+
:returns: the status dict of the plugin
:rtype: dict
"""
@@ -262,7 +262,7 @@ class Core(CorePluginBase):
def on_download_complete(self, blocklist):
"""
Runs any download clean up functions
-
+
:param blocklist: path of blocklist
:type blocklist: string
:returns: a Deferred which fires when clean up is done
@@ -275,8 +275,8 @@ class Core(CorePluginBase):
def on_download_error(self, f):
"""
Recovers from download error
-
- :param f: failure that occured
+
+ :param f: failure that occurred
:type f: Failure
:returns: a Deferred if recovery was possible
else the original failure
@@ -311,7 +311,7 @@ class Core(CorePluginBase):
def import_list(self, blocklist):
"""
Imports the downloaded blocklist into the session
-
+
:param blocklist: path of blocklist
:type blocklist: string
:returns: a Deferred that fires when the blocklist has been imported
@@ -335,7 +335,7 @@ class Core(CorePluginBase):
self.is_importing = True
self.num_blocked = 0
self.blocklist = self.core.session.get_ip_filter()
-
+
if not blocklist:
blocklist = self.filename
@@ -353,7 +353,7 @@ class Core(CorePluginBase):
def on_import_complete(self, blocklist):
"""
Runs any import clean up functions
-
+
:param blocklist: path of blocklist
:type blocklist: string
:returns: a Deferred that fires when clean up is done
@@ -376,8 +376,8 @@ class Core(CorePluginBase):
def on_import_error(self, f):
"""
Recovers from import error
-
- :param f: failure that occured
+
+ :param f: failure that occurred
:type f: Failure
:returns: a Deferred if recovery was possible
else the original failure
diff --git a/deluge/ui/tracker_icons.py b/deluge/ui/tracker_icons.py
index c31732031..02aa50570 100644
--- a/deluge/ui/tracker_icons.py
+++ b/deluge/ui/tracker_icons.py
@@ -244,7 +244,7 @@ class TrackerIcons(Component):
"""
Recovers from download error
- :param f: the failure that occured
+ :param f: the failure that occurred
:type f: Failure
:param host: the name of the host whose page failed to download
:type host: string
@@ -311,7 +311,7 @@ class TrackerIcons(Component):
"""
Recovers from a parse error
- :param f: the failure that occured
+ :param f: the failure that occurred
:type f: Failure
:returns: a Deferred if recovery was possible
else the original failure
@@ -383,7 +383,7 @@ class TrackerIcons(Component):
"""
Recovers from a download error
- :param f: the failure that occured
+ :param f: the failure that occurred
:type f: Failure
:param host: the host the icon failed to download for
:type host: string
diff --git a/deluge/ui/web/json_api.py b/deluge/ui/web/json_api.py
index 8877032b9..a70d174ce 100644
--- a/deluge/ui/web/json_api.py
+++ b/deluge/ui/web/json_api.py
@@ -242,7 +242,7 @@ class JSON(resource.Resource, component.Component):
def _on_rpc_request_failed(self, reason, response, request):
"""
Handles any failures that occured while making an rpc call.
"""
request.setResponseCode(http.INTERNAL_SERVER_ERROR)
return ""
@@ -658,7 +658,7 @@ class WebApi(JSONComponent):
allow_compression=False)
result.addCallbacks(on_download_success, on_download_fail)
else:
- log.error("Error occured downloading torrent from %s", url)
+ log.error("Error occurred downloading torrent from %s", url)
log.error("Reason: %s", result.getErrorMessage())
return result
@@ -871,7 +871,7 @@ class WebApi(JSONComponent):
d.addCallback(on_connect, c)
d.addErrback(on_connect_failed)
except:
- main_deferred.callback((False, "An error occured"))
+ main_deferred.callback((False, "An error occurred"))
return main_deferred
@export
@@ -242,7 +242,7 @@ class JSON(resource.Resource, component.Component):
def _on_rpc_request_failed(self, reason, response, request):
"""
- Handles any failures that occured while making an rpc call.
+ Handles any failures that occurred while making an rpc call.
"""
request.setResponseCode(http.INTERNAL_SERVER_ERROR)